@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import PackageFormatType, PackageVersionStatusType
 from .paginator import (
@@ -91,26 +91,35 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class CodeArtifactClient:
+class CodeArtifactClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CodeArtifactClient exceptions.
+        """
 
     def associate_external_connection(
         self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = None
     ) -> AssociateExternalConnectionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
+        Adds an existing external connection to a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.associate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#associate_external_connection)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#can_paginate)
         """
 
@@ -130,7 +139,10 @@ class CodeArtifactClient:
         includeFromUpstream: bool = None
     ) -> CopyPackageVersionsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
+        Copies package versions from one repository to another repository in the same
+        domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.copy_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#copy_package_versions)
         """
 
@@ -138,7 +150,9 @@ class CodeArtifactClient:
         self, *, domain: str, encryptionKey: str = None, tags: List["TagTypeDef"] = None
     ) -> CreateDomainResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
+        Creates a domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_domain)
         """
 
@@ -149,17 +163,21 @@ class CodeArtifactClient:
         repository: str,
         domainOwner: str = None,
         description: str = None,
-        upstreams: List[UpstreamRepositoryTypeDef] = None,
+        upstreams: List["UpstreamRepositoryTypeDef"] = None,
         tags: List["TagTypeDef"] = None
     ) -> CreateRepositoryResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
+        Creates a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.create_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#create_repository)
         """
 
     def delete_domain(self, *, domain: str, domainOwner: str = None) -> DeleteDomainResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
+        Deletes a domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain)
         """
 
@@ -167,7 +185,9 @@ class CodeArtifactClient:
         self, *, domain: str, domainOwner: str = None, policyRevision: str = None
     ) -> DeleteDomainPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
+        Deletes the resource policy set on a domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.delete_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_domain_permissions_policy)
         """
 
@@ -184,7 +204,9 @@ class CodeArtifactClient:
         expectedStatus: PackageVersionStatusType = None
     ) -> DeletePackageVersionsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
+        Deletes one or more versions of a package.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.delete_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_package_versions)
         """
 
@@ -192,7 +214,9 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, domainOwner: str = None
     ) -> DeleteRepositoryResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
+        Deletes a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository)
         """
 
@@ -200,7 +224,9 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, domainOwner: str = None, policyRevision: str = None
     ) -> DeleteRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
+        Deletes the resource policy that is set on a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.delete_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#delete_repository_permissions_policy)
         """
 
@@ -208,7 +234,11 @@ class CodeArtifactClient:
         self, *, domain: str, domainOwner: str = None
     ) -> DescribeDomainResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
+        Returns a `DomainDescription <https://docs.aws.amazon.com/codeartifact/latest/AP
+        IReference/API_DomainDescription.html>`__ object that contains information about
+        the requested domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_domain)
         """
 
@@ -224,7 +254,11 @@ class CodeArtifactClient:
         namespace: str = None
     ) -> DescribePackageVersionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
+        Returns a `PackageVersionDescription <https://docs.aws.amazon.com/codeartifact/l
+        atest/APIReference/API_PackageVersionDescription.html>`__ object that contains
+        information about the requested package version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.describe_package_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_package_version)
         """
 
@@ -232,7 +266,10 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, domainOwner: str = None
     ) -> DescribeRepositoryResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
+        Returns a `RepositoryDescription` object that contains detailed information
+        about the requested repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.describe_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#describe_repository)
         """
 
@@ -240,7 +277,9 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, externalConnection: str, domainOwner: str = None
     ) -> DisassociateExternalConnectionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
+        Removes an existing external connection from a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.disassociate_external_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#disassociate_external_connection)
         """
 
@@ -258,7 +297,10 @@ class CodeArtifactClient:
         expectedStatus: PackageVersionStatusType = None
     ) -> DisposePackageVersionsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
+        Deletes the assets in package versions and sets the package versions' status to
+        `Disposed`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.dispose_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#dispose_package_versions)
         """
 
@@ -270,7 +312,9 @@ class CodeArtifactClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#generate_presigned_url)
         """
 
@@ -278,7 +322,10 @@ class CodeArtifactClient:
         self, *, domain: str, domainOwner: str = None, durationSeconds: int = None
     ) -> GetAuthorizationTokenResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
+        Generates a temporary authorization token for accessing repositories in the
+        domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_authorization_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_authorization_token)
         """
 
@@ -286,7 +333,9 @@ class CodeArtifactClient:
         self, *, domain: str, domainOwner: str = None
     ) -> GetDomainPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
+        Returns the resource policy attached to the specified domain.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_domain_permissions_policy)
         """
 
@@ -304,7 +353,9 @@ class CodeArtifactClient:
         packageVersionRevision: str = None
     ) -> GetPackageVersionAssetResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
+        Returns an asset (or file) that is in a package.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_asset)
         """
 
@@ -320,7 +371,9 @@ class CodeArtifactClient:
         namespace: str = None
     ) -> GetPackageVersionReadmeResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
+        Gets the readme file or descriptive text for a package version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_package_version_readme)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_package_version_readme)
         """
 
@@ -328,7 +381,9 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, format: PackageFormatType, domainOwner: str = None
     ) -> GetRepositoryEndpointResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
+        Returns the endpoint of a repository for a specific package format.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_endpoint)
         """
 
@@ -336,7 +391,9 @@ class CodeArtifactClient:
         self, *, domain: str, repository: str, domainOwner: str = None
     ) -> GetRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
+        Returns the resource policy that is set on a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.get_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#get_repository_permissions_policy)
         """
 
@@ -344,7 +401,11 @@ class CodeArtifactClient:
         self, *, maxResults: int = None, nextToken: str = None
     ) -> ListDomainsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
+        Returns a list of `DomainSummary <https://docs.aws.amazon.com/codeartifact/lates
+        t/APIReference/API_PackageVersionDescription.html>`__ objects for all domains
+        owned by the AWS account that makes this call.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_domains)
         """
 
@@ -362,7 +423,10 @@ class CodeArtifactClient:
         nextToken: str = None
     ) -> ListPackageVersionAssetsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
+        Returns a list of `AssetSummary <https://docs.aws.amazon.com/codeartifact/latest
+        /APIReference/API_AssetSummary.html>`__ objects for assets in a package version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_assets)
         """
 
@@ -379,7 +443,9 @@ class CodeArtifactClient:
         nextToken: str = None
     ) -> ListPackageVersionDependenciesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
+        Returns the direct dependencies for a package version.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_package_version_dependencies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_version_dependencies)
         """
 
@@ -398,7 +464,11 @@ class CodeArtifactClient:
         nextToken: str = None
     ) -> ListPackageVersionsResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
+        Returns a list of `PackageVersionSummary <https://docs.aws.amazon.com/codeartifa
+        ct/latest/APIReference/API_PackageVersionSummary.html>`__ objects for package
+        versions in a repository that match the request parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_package_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_package_versions)
         """
 
@@ -415,7 +485,11 @@ class CodeArtifactClient:
         nextToken: str = None
     ) -> ListPackagesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
+        Returns a list of `PackageSummary <https://docs.aws.amazon.com/codeartifact/late
+        st/APIReference/API_PackageSummary.html>`__ objects for packages in a repository
+        that match the request parameters.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_packages)
         """
 
@@ -423,7 +497,10 @@ class CodeArtifactClient:
         self, *, repositoryPrefix: str = None, maxResults: int = None, nextToken: str = None
     ) -> ListRepositoriesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
+        Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
+        atest/APIReference/API_RepositorySummary.html>`__ objects.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories)
         """
 
@@ -438,13 +515,19 @@ class CodeArtifactClient:
         nextToken: str = None
     ) -> ListRepositoriesInDomainResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
+        Returns a list of `RepositorySummary <https://docs.aws.amazon.com/codeartifact/l
+        atest/APIReference/API_RepositorySummary.html>`__ objects.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_repositories_in_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_repositories_in_domain)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
+        Gets information about AWS tags for a specified Amazon Resource Name (ARN) in
+        AWS CodeArtifact.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#list_tags_for_resource)
         """
 
@@ -457,7 +540,9 @@ class CodeArtifactClient:
         policyRevision: str = None
     ) -> PutDomainPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
+        Sets a resource policy on a domain that specifies permissions to access it.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.put_domain_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_domain_permissions_policy)
         """
 
@@ -471,19 +556,26 @@ class CodeArtifactClient:
         policyRevision: str = None
     ) -> PutRepositoryPermissionsPolicyResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
+        Sets the resource policy on a repository that specifies permissions to access
+        it.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.put_repository_permissions_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#put_repository_permissions_policy)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
+        Adds or updates tags for a resource in AWS CodeArtifact.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
+        Removes tags from a resource in AWS CodeArtifact.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#untag_resource)
         """
 
@@ -502,7 +594,9 @@ class CodeArtifactClient:
         expectedStatus: PackageVersionStatusType = None
     ) -> UpdatePackageVersionsStatusResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
+        Updates the status of one or more versions of a package.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.update_package_versions_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_package_versions_status)
         """
 
@@ -513,17 +607,20 @@ class CodeArtifactClient:
         repository: str,
         domainOwner: str = None,
         description: str = None,
-        upstreams: List[UpstreamRepositoryTypeDef] = None
+        upstreams: List["UpstreamRepositoryTypeDef"] = None
     ) -> UpdateRepositoryResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
+        Update the properties of a repository.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Client.update_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/client.html#update_repository)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listdomainspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListDomains)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listdomainspaginator)
         """
 
     @overload
@@ -531,7 +628,8 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_package_version_assets"]
     ) -> ListPackageVersionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionassetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersionAssets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionassetspaginator)
         """
 
     @overload
@@ -539,13 +637,15 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_package_versions"]
     ) -> ListPackageVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackageVersions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackageversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_packages"]) -> ListPackagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackagespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListPackages)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listpackagespaginator)
         """
 
     @overload
@@ -553,7 +653,8 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_repositories"]
     ) -> ListRepositoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositories)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriespaginator)
         """
 
     @overload
@@ -561,5 +662,6 @@ class CodeArtifactClient:
         self, operation_name: Literal["list_repositories_in_domain"]
     ) -> ListRepositoriesInDomainPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriesindomainpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.111/reference/services/codeartifact.html#CodeArtifact.Paginator.ListRepositoriesInDomain)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/paginators.html#listrepositoriesindomainpaginator)
         """
